import sys
import typing


def create_from_info(shader_info):
    ''' Create shader from a GPUShaderCreateInfo.

    :param shader_info: GPUShaderCreateInfo
    :return: Shader object corresponding to the given name.
    '''

    pass


def from_builtin(shader_name, config='DEFAULT'):
    ''' Shaders that are embedded in the blender internal code:

    '''

    pass


def unbind():
    ''' Unbind the bound shader object.

    '''

    pass
